#
# spec file for package python-oslo.policy
#
# Copyright (c) 2020 SUSE LLC
#
# All modifications and additions to the file contributed by third parties
# remain the property of their copyright owners, unless otherwise agreed
# upon. The license for this file, and modifications and additions to the
# file, is the same license as for the pristine package itself (unless the
# license for the pristine package is not an Open Source License, in which
# case the license is the MIT License). An "Open Source License" is a
# license that conforms to the Open Source Definition (Version 1.9)
# published by the Open Source Initiative.

# Please submit bugfixes or comments via https://bugs.opensuse.org/
#


Name:           python-oslo.policy
Version:        3.1.0
Release:        bp156.3.1
Summary:        OpenStack Oslo Policy library
License:        Apache-2.0
Group:          Development/Languages/Python
URL:            https://launchpad.net/oslo.policy
Source0:        https://files.pythonhosted.org/packages/source/o/oslo.policy/oslo.policy-3.1.0.tar.gz
BuildRequires:  openstack-macros
BuildRequires:  python3-PyYAML >= 3.12
BuildRequires:  python3-oslo.config >= 5.2.0
BuildRequires:  python3-oslo.context >= 2.22.0
BuildRequires:  python3-oslo.i18n >= 3.15.3
BuildRequires:  python3-oslo.serialization >= 2.18.0
BuildRequires:  python3-oslo.utils >= 3.40.0
BuildRequires:  python3-oslotest
BuildRequires:  python3-pbr
BuildRequires:  python3-requests >= 2.14.2
BuildRequires:  python3-requests-mock
BuildRequires:  python3-stestr
BuildArch:      noarch

%description
The OpenStack Oslo Policy library.
RBAC policy enforcement library for OpenStack.

%package -n python3-oslo.policy
Summary:        OpenStack Oslo Policy library
Group:          Development/Languages/Python
Requires:       python3-PyYAML >= 3.12
Requires:       python3-oslo.config >= 5.2.0
Requires:       python3-oslo.context >= 2.22.0
Requires:       python3-oslo.i18n >= 3.15.3
Requires:       python3-oslo.serialization >= 2.18.0
Requires:       python3-oslo.utils >= 3.40.0
Requires:       python3-requests >= 2.14.2
Requires:       python3-six >= 1.10.0
Requires:       python3-stevedore >= 1.20.0
%if 0%{?suse_version}
Obsoletes:      python2-oslo.policy < 2.4.1
%endif

%description -n python3-oslo.policy
The OpenStack Oslo Policy library.
RBAC policy enforcement library for OpenStack.

This package contains the Python 3.x module.

%package -n python-oslo.policy-doc
Summary:        Documentation for the Oslo Policy library
Group:          Documentation/HTML
BuildRequires:  python3-Sphinx
BuildRequires:  python3-openstackdocstheme
BuildRequires:  python3-sphinxcontrib-apidoc

%description -n python-oslo.policy-doc
Documentation for the Oslo Policy library.

%prep
%autosetup -p1 -n oslo.policy-3.1.0
%py_req_cleanup

%build
%{py3_build}

# generate html docs
PBR_VERSION=%{version} %sphinx_build -b html doc/source doc/build/html
# remove the sphinx-build leftovers
rm -rf doc/build/html/.{doctrees,buildinfo}

%install
%{py3_install}

%check
python3 -m stestr.cli run

%files  -n python3-oslo.policy
%license LICENSE
%doc README.rst
%{_bindir}/oslopolicy-checker
%{_bindir}/oslopolicy-list-redundant
%{_bindir}/oslopolicy-policy-generator
%{_bindir}/oslopolicy-sample-generator
%{_bindir}/oslopolicy-policy-upgrade
%{python3_sitelib}/oslo_policy
%{python3_sitelib}/*.egg-info

%files -n python-oslo.policy-doc
%license LICENSE
%doc doc/build/html

%changelog
* Tue May 12 2020 cloud-devel@suse.de
- update to version 3.1.0
  - Fix reference cycle caused by deprecated sample override
  - Bump the openstackdocstheme extension to 1.20
  - tox: Trivial cleanup
  - Fix doc comments for new enforce default flag
  - [ussuri][goal] Drop python 2.7 support and testing
  - Use unittest.mock instead of third party mock
  - Update hacking for Python3
  - Add new config to enforce the new defaults
  - Allow disabling the default check_str change warnings
  - Initialize global config object in cli tools
  - Bump oslo.utils to 3.40.0
  - Temporarily make namespace arg optional
  - Link to the Keystone role documentation
  - Follow the new PTI for document build
  - Don't use string processing to combine deprecated rules
  - Modernize policy checker
  - Don't parse cli args on the global object in sphinxpolicygen
  - Make HTTP check doc heading more specific
  - Cleanup warnings
  - Update master for stable/train
  - Suppress deprecation warnings in oslopolicy-list-redundant
  - tox: Keeping going with docs
  - remove outdated header
  - Update the constraints url
  - Switch to Ussuri jobs
  - Move away from python setup.py test who is deprecated in pbr
* Sat Mar 14 2020 Dirk Mueller <dmueller@suse.com>
- switch to python 3.x only builds
* Tue Mar 10 2020 cloud-devel@suse.de
- update to version 2.3.3
  - Modernize policy checker
  - Fix reference cycle caused by deprecated sample override
  - Update TOX/UPPER_CONSTRAINTS_FILE for stable/train
  - Update .gitreview for stable/train
  - Suppress deprecation warnings in oslopolicy-list-redundant
* Wed Oct  9 2019 cloud-devel@suse.de
- update to version 2.3.2
  - Dropping the py35 testing
  - Add Python 3 Train unit tests
  - Clarify policy_file configuration option help text
  - Corrects tox.ini snippet to point to config file
  - Replace git.openstack.org URLs with opendev.org URLs
  - Add attribute to suppress deprecation warnings
  - Add unit tests on the sphinxext indent function
  - Cap Bandit below 1.6.0 and update Sphinx requirement
  - Updated from global requirements
  - Add py36 and py37 tox envs
  - Only alias when policy names change
  - Move doc related modules to doc/requirements.txt
  - Provide more specific error when namespace is missing
  - OpenDev Migration Patch
  - Update master for stable/stein
* Mon Apr  8 2019 cloud-devel@suse.de
- update to version 2.1.1
  - Use template for lower-constraints
  - Fix sample config value when set_defaults is used
  - Imported Translations from Zanata
  - sphinxext: Start parsing 'DocumentedRuleDefault.description' as rST
  - Remove PyPI downloads
  - Fully log RBAC enforcement data
  - Add ability to pass in target data for the oslopolicy-checker
  - Add guidelines for naming policies
  - Prevent sensitive target data from being logged
  - generator: Reimplement wrapping of 'description'
  - Change openstack-dev to openstack-discuss
  - import zuul job settings from project-config
  - oslopolicy-checker: iterate through rules in sorted order
  - Update reno for stable/rocky
  - add python 3.6 unit test job
  - Add domain scope support for scope types
  - Correct typo in docs
  - Unit test for CLI
  - Add docs for developers testing APIs
  - add lib-forward-testing-python3 test job
  - Move _capture_stdout to a common place
  - Use oslo.config instead of argparse.
  - Pass in policy name as part of the oslopolicy-check check call
  - Add minor nits in testing documentation
  - Docs: Remove references to JSON format
  - Add ability for policy-checker to read configuration
  - Add policy-upgrade tool
  - Fix usage of token fixture in shell tests
  - Fixes is_admin type from StrOpt to BoolOpt.
  - Fixes file access using with statements.
  - Update hacking version
  - Make upgrades more robust with policy overrides
  - Clean up .gitignore references to personal tools
  - Enhance test to prevent JSON parsing regression
  - Update sphinx extension logging
  - add python 3.7 unit test job
* Thu Sep 20 2018 cloud-devel@suse.de
- update to version 1.38.1
  - Pass dictionary as creds in policy tests
  - fix tox python3 overrides
  - trivial: Fix file permissions
  - Add CLI usage documentation
  - Add blueprints and releasenotes link to README
  - Teach Enforcer.enforce to deal with context objects
  - Avoid redundant policy syntax checks
  - Add examples and clarification around scope_types
  - Fix requirements and convert to stestr
  - Clarify CLI documentation
* Mon Sep  3 2018 cloud-devel@suse.de
- update to version 1.37.0
  - Remove stale pip-missing-reqs tox test
  - Update sphinxext to include scope_types in docs
  - set default python to python3
  - Fix document formatting
  - Update reno for stable/queens
  - Update links in README
  - make the sphinxpolicygen extension handle multiple input/output files
  - Render deprecated policy names when generating files
  - Remove erroneous newline in sample generation
  - Update documentation to include usage for new projects
  - Include deprecated_reason when deprecated_rule is set
  - Imported Translations from Zanata
  - Trivial: Update pypi url to new url
  - Updated from global requirements
  - add lower-constraints job
  - Include both new and deprecated rules in generated sample
* Fri Feb 23 2018 tbechtold@suse.com
- Switch to stable/queens spec template
* Wed Jan 17 2018 dmueller@suse.com
- convert to singlespec
* Mon Jan 15 2018 cloud-devel@suse.de
- update to version 1.33.1
  - Fix string injection for InvalidScope
  - Imported Translations from Zanata
  - Avoid tox_install.sh for constraints support
  - add bandit to pep8 job
  - Add JSON output option to sample generator
  - External Policy hook should support SSL
  - rewrite HttpCheckFixture to not mock out entire HttpCheck class
  - http/https check rules as stevedore extensions
  - Add functionality to deprecate policies
  - Handle deprecation of inspect.getargspec
  - Documentation and release notes for plugins
  - Remove -U from pip install
  - Modification to add additional information in the HTTPCheck request.
  - fix formatting for empty defaults
  - Add scope_types to RuleDefault objects
  - Pass creds as a dict in tests
  - Only log deprecation warnings when they are overridden
  - throw an exception when sphinxext cannot find the config file
  - Update reno for stable/pike
  - Remove setting of version/release from releasenotes
  - expand type documentation for Enforcer arguments
  - Add configuration option for enforcing scope
  - Updated from global requirements
  - Add a release note for enforce_scope
* Mon Aug  7 2017 cloud-devel@suse.de
- update to version 1.25.1
  - Fix parsing bug when config file is empty.
  - Modify tests in test_generator
  - fix formatting for empty defaults
  - Simplify message of exception PolicyNotAuthorized
  - [Fix gate]Update test requirement
  - Add additional param to policy.RuleDefault
  - Update reno for stable/ocata
  - Check reStructuredText documents for common style issues.
  - switch from oslosphinx to openstackdocstheme
  - Add release note for DocumentedRuleDefault
  - Optimize the link address
  - Update UPPER_CONSTRAINTS_FILE for stable/pike
  - Update usage documentation
  - move existing documentation into new standard layout
  - Add optional exception for check_rules
  - pbr.version.VersionInfo needs package name (oslo.xyz and not oslo_xyz)
  - Update URLs in documents according to document migration
  - import configuration guide content from openstack-manuals repo
  - throw an exception when sphinxext cannot find the config file
  - oslopolicy-sample-generator description support
  - sphinxext: Format definition lists correctly
  - Comment out the rule from generated sample-policy file
  - Allow multiline descriptions for RuleDefaults
  - Update .gitreview for stable/pike
  - Remove log translations
  - Delete the unnecessary word in policy.py
  - Add Sphinx extension to pretty-print modules
  - Remove support for py34
  - sphinxext: Use field lists in output
  - Updated from global requirements
  - Seperate each policy rule with new line
  - Use Sphinx 1.5 warning-is-error
* Fri Feb 10 2017 cloud-devel@suse.de
- update to version 1.18.0:
  - Add missing parameter description in module _cache_handler
  - Imported Translations from Zanata
  - Enable release notes translation
  - Remove dead code and use default value of argparse.
  - Remove oslo.utils from requirements
  - Update reno for stable/newton
  - Remove references to Python 3.4
  - Change assertTrue(isinstance()) by optimal assert
  - Add stevedore to requirements
  - Show team and repo badges on README
  - Improved performance of parse_file_contents() method
  - Doc: declare YAML/JSON support
  - Remove wrong parameter type for class NotCheck from docstring
  - Add sphinx extension to build sample policy
  - Perform basic checks on policy definitions
  - Update docs on policy sample generator
  - Fix a code logic while doing cyclical reference check to the policy
  - doc: Add introduction to index page
  - Add Constraints support
  - Changed the home-page link
  - Fix typo in oslo.policy
  - Make exception PolicyNotAuthorized more readable
  - Updated from global requirements
* Fri Oct 14 2016 tbechtold@suse.com
- switch to stable/newton tarball in _service
* Wed Aug 31 2016 tbechtold@suse.com
- update to version 1.14.0
  * Revert "Adds debug logging for policy file validation"
  * Delete H803 in flake8 ignore
  * Allow policy file to not exist
  * Updated from global requirements
* Wed Aug 10 2016 tbechtold@suse.com
- update to version 1.13.0
  * Fix mispelled method name in setup.cfg
  * Add note about not all APIs support policy enforcement by user_id
  * Imported Translations from Zanata
  * Fixed unit tests running on Windows
  * Add Python 3.5 classifier and venv
  * Adds debug logging for policy file validation
  * Updated from global requirements
* Mon Jul  4 2016 tbechtold@suse.com
- update to 1.11.0:
  * Updated from global requirements
  * Imported Translations from Zanata
  * Improve policy sample generation testing
  * Add helper scripts for generating policy info
* Mon Jul  4 2016 tbechtold@suse.com
- update to 1.9.0:
  * Add sample file generation script and helper methods
  * Add equality operator to policy.RuleDefault
  * Imported Translations from Zanata
  * Updated from global requirements
  * Fix typo: 'olso' to 'oslo'
  * Updated from global requirements
  * Updated from global requirements
  * Add reno for release notes management
  * Add policy registration and authorize method
  * Updated from global requirements
  * doc: Fix wrong import statement in usage
* Sat Jun  4 2016 tbechtold@suse.com
- update to 1.8.0:
  * Trivial: ignore openstack/common in flake8 exclude list
  * Updated from global requirements
  * Imported Translations from Zanata
  * Deprecate load_json() in favor of load()
  * Support policy file in YAML
- use renderspec source service
- update spec from upstream
* Thu Mar  3 2016 tbechtold@suse.com
- update to 1.5.0:
  * Updated from global requirements
  * Update translation setup
  * Updated from global requirements
  * Updated from global requirements
  * Updated from global requirements
  * Updated from global requirements
  * Revert "Pass environment variables of proxy to tox"
  * Run docs testenv by default with tox
  * Add oslopolicy-checker command-line tool
  * Updated from global requirements
  * Don't crash on RoleCheck when roles not present
  * assertIsNone(val) instead of assertEqual(None,val)
  * Updated from global requirements
  * Add string format rendering to RoleCheck.__call__()
  * Pass environment variables of proxy to tox
  * Fixes combined "and" and "or" rule handling
  * Make sure item of policy_dirs is directory
  * Updated from global requirements
  * Use dict comprehension
  * Don't generate doc from test
  * Trival: Remove 'MANIFEST.in'
  * Updated from global requirements
  * Updated from global requirements
  * Updated from global requirements
  * Use requests-mock instead of httpretty in tests
  * Clarify usage docs
  * Correct invalid doc references
  * Updated from global requirements
  * Remove Python 2.6 classifier
  * Remove python 2.6 and cleanup tox.ini
  * Updated from global requirements
  * Updated from global requirements
  * Updated from global requirements
  * Use JSON generator
  * Add test for enforce with rule doesn't exist
  * Add test for raising default exception
  * Add test for invalid JSON
  * Add cover test requirement
  * Fix a typo in policy.py
  * Updated from global requirements
  * Custom fixture to avoid external call in HttpCheck
  * Fix coverage configuration and execution
  * add auto-generated docs for config options
  * Add shields.io version/downloads links/badges into README.rst
  * Updated from global requirements
  * Use requests in http check instead of urllib
  * Change ignore-errors to ignore_errors
  * Updated from global requirements
  * remove deprecation text for policy_dirs option
- Switch to .spec from rpm-packaging upstream project
* Wed Sep  9 2015 tbechtold@suse.com
- update to 0.11.0:
  * Updated from global requirements
  * Pass reference then actual to assertEqual
  * Overwrite option should not cause policy file reloading
  * Updated from global requirements
  * Setup translations
  * Have the enforcer have its own file cache
  * Updated from global requirements
  * Updated from global requirements
- adjust Requires according requirements.txt
* Tue Jul 28 2015 tbechtold@suse.com
- update to 0.8.0:
  * Updated from global requirements
  * Fix typo of 'available' in token_fixture.py
  * Fixes up the API docs and module index
- adjust Requires according requirements.txt
* Fri Jul 17 2015 tbechtold@suse.com
- update to 0.7.0:
  * Remove oslo-incubator specific code
  * Move fileutils functions to oslo.policy
  * Add six and oslo.utils to requirements
  * Add tox target to find missing requirements
  * Updated from global requirements
  * Updated from global requirements
- Update Requires according to requirements.txt
* Wed Jun 10 2015 tbechtold@suse.com
- update to 0.6.0:
  * Fix Enforcer docstring
- Run testsuite in parallel
* Mon Jun  8 2015 tbechtold@suse.com
- update to 0.5.0:
  * Expose base check classes as part of public API
  * Uncap library requirements for liberty
  * Fix invalid indentation in _load_policy_file method
  * Cleanup README.rst and setup.cfg
  * Avoid reloading policy files in policy.d for every call
  * Lists for Generic Checks
  * Updated from global requirements
- Update Requires according to requirements.txt
* Mon Jun  1 2015 dmueller@suse.com
- remove wildcards from the filelist
* Mon Mar 16 2015 tbechtold@suse.com
- Enable tests during build
- Adjust Requires and BuildRequires
* Mon Mar 16 2015 tbechtold@suse.com
- Initial packaging
